@@ -3,19 +3,13 @@
 #include <math.h>
 #include <stdarg.h>
 #include <string.h>
-
-#include "io_lib_header.h"
-#include "util_lib_header.h"
-#include "define_header.h"
-#include "dp_lib_header.h"
+#include <sys/sysctl.h>
 #include "dev3_lib_header.h"
-
-//Insert functions here
 /*********************************COPYRIGHT NOTICE**********************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
