@@ -175,6 +175,7 @@ int glocal2_pair_wise (Alignment *A,int*ns, int **ls,Constraint_list *CL);
 int gotoh_pair_wise_lgp_sticky ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int clinked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
+int cl2pair_list_ecl_ext_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
 void free_proba_pair_wise();
 
 int subop1_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL);
@@ -815,7 +816,7 @@ Sequence *pavie_seq2noisy_seq (Sequence *S, int val,char *subst);
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
