@@ -2750,7 +2750,7 @@ char * rna_struc2rna_lib ( char *seq_name, char *seq, char *name)
   if ( name==NULL)name=vtmpnam(NULL);
   fp=vfopen ( name, "w");
   fprintf (fp, "! TC_LIB_FORMAT_01\n");
-  fprintf (fp, "1\n%s %d %s\n", seq_name, strlen (seq), seq);
+  fprintf (fp, "1\n%s %d %s\n", seq_name, (int)strlen (seq), seq);
   fprintf (fp, "#1 1\n");
   display_rna_ss (0, seq, st, fp);
   fprintf ( fp, "! SEQ_1_TO_N\n");
@@ -2787,7 +2787,7 @@ int display_rna_ss ( int n, char *seq, char *st, FILE *fp)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
