@@ -268,13 +268,15 @@ int ** read_matrice (char *mat_name_in)
 	{
 	int a,b,c, l;
 
-	char AA[]="abcdefghiklmnpqrstvwxyz";
+	char *AA;
         FILE *fp;
 	int **matrice;
 	int **matrix2;
 	char mat_name[200];
 	int *vector=NULL;
 	
+	AA=vcalloc (256, sizeof (char));
+	sprintf (AA, "abcdefghiklmnpqrstvwxyz");
 	l=strlen(AA);
 
 	
@@ -1183,7 +1185,12 @@ void output_hit_matrix(char *fileName, float **ffpHitScoreMatrix, int nl)
 	}
 	vfclose(fp);
 }
-
+int output_hit_color_format (Alignment *B, float **ffPScoreTable, int nl, char *name, \
+FILE_format *(*vfopen_format)          ( char *),\
+FILE_format *(*print_format_string)    ( char * ,Color *, Color *, FILE_format*),\
+FILE_format *(*print_format_char)      ( int    ,Color *, Color *, FILE_format*),\
+void         (*get_rgb_values_format)  ( int    ,Color *),\
+FILE_format* (*vfclose_format)         ( FILE_format *));
 int output_hit_color_html (Alignment *B, float **ffPScoreTable, int nl, char *name)
 {
    output_hit_color_format (B, ffPScoreTable, nl, name, vfopen_html,print_html_string,print_html_char,get_rgb_values_html, vfclose_html);
@@ -1495,7 +1502,7 @@ int       output_seq_reliability_ascii     ( Alignment *B,Alignment *S, char *na
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
