@@ -348,7 +348,8 @@ Ca_trace * simple_read_ca_trace (char *tp_name )
 	       
 	       T->seq[A->res_num-1]=res;
 
-	       if ( strm ( A->type, "CA")) T->ca[A->res_num-1]=A;
+	       if (( strm ( A->type, "CA")) || ( strm ( A->type, "C3'")))
+			   T->ca[A->res_num-1]=A;
 	       a++;
 	   }
 	T->n_atom=a;
@@ -360,6 +361,7 @@ Ca_trace * simple_read_ca_trace (char *tp_name )
 	    A=T->structure[a];
 
 	    if ( strm (A->type, "CA"))(T->peptide_chain[A->res_num-1])->CA=A;
+		if ( strm (A->type, "C3'"))(T->peptide_chain[A->res_num-1])->CA=A;
 	    if ( strm (A->type, "C"))(T->peptide_chain[A->res_num-1] )->C=A;
 	    if ( strm (A->type, "CB"))(T->peptide_chain[A->res_num-1])->CB=A;
 	    if ( strm (A->type, "N"))(T->peptide_chain[A->res_num-1] )->N=A;
@@ -1004,7 +1006,7 @@ char **struc2nb (char *name,char *seq, char *comment, float Threshold, char *ato
 short **seq2nb (char *seq, char *pdb, float Threshold, char *atom)
 {
   char *struc_file;
-  char *struc_name;
+ 
   Ca_trace *T;
   Atom *A1, *A2;
   int a, b;
@@ -1015,7 +1017,7 @@ short **seq2nb (char *seq, char *pdb, float Threshold, char *atom)
 
   // get a clean pdb file
   struc_file=vtmpnam (NULL);
-  if ( check_file_exists (struc_file) && is_simple_pdb_file(struc_name))
+  if ( check_file_exists (struc_file) && is_simple_pdb_file(struc_file))
     {
       sprintf (command, "cp %s %s", pdb, struc_file);
     }
@@ -1066,7 +1068,7 @@ short **seq2nb (char *seq, char *pdb, float Threshold, char *atom)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
