@@ -1352,7 +1352,7 @@ int list2nodup_list ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int
 }
 int** cl2sorted_diagonals   ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
 {
-  if ( CL && CL->L)return cl2sorted_diagonals_cs   ( A, ns, ls, CL);
+  if ( CL && CL->residue_index)return cl2sorted_diagonals_cs   ( A, ns, ls, CL);
   else return cl2sorted_diagonals_mat   ( A, ns, ls, CL);
 }
 
@@ -1389,12 +1389,12 @@ int** cl2sorted_diagonals_mat  ( Alignment *A, int *ns, int **ls, Constraint_lis
  
   for ( a=0; a<ns[0]; a++)
     {
-      sprintf (buf1, A->seq_al[ls[0][a]]);
+      sprintf (buf1, "%s",A->seq_al[ls[0][a]]);
       lower_string (buf1);
       string_convert (buf1, alps, alp);
       for (b=0; b<ns[1]; b++)
 	{
-	  sprintf (buf2, A->seq_al[ls[1][b]]);
+	  sprintf (buf2,"%s", A->seq_al[ls[1][b]]);
 	  lower_string (buf2);
 	  string_convert (buf2, alps, alp);
 	  for (c=0; c<l1-k; c++)
@@ -1543,7 +1543,6 @@ int** cl2sorted_diagonals_cs   ( Alignment *A, int *ns, int **ls, Constraint_lis
   
   
 
-  CL=index_res_constraint_list (CL, CL->weight_field);
   ndiag=l1+l2;
   diag=declare_int (ndiag+3, 2);
   
@@ -1597,7 +1596,7 @@ int** cl2sorted_diagonals_cs_old2   ( Alignment *A, int *ns, int **ls, Constrain
   sl2=vcalloc ((CL->S)->nseq, sizeof (int));
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
-  CL=index_res_constraint_list (CL, CL->weight_field);
+  
   ndiag=l1+l2;
   diag=declare_int (ndiag+3, 2);
   
@@ -1609,11 +1608,11 @@ int** cl2sorted_diagonals_cs_old2   ( Alignment *A, int *ns, int **ls, Constrain
 	  s=ls [0][si];
 	  r=pos[s][p1-1];
 	  
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
 	      
-	      t_s=CL->residue_index[s][r][a];
-	      t_r=CL->residue_index[s][r][a+1];
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
 	      
 	      if (sl2[t_s])
 		{
@@ -1653,11 +1652,11 @@ int cl2list_borders   (Alignment *A, int *ns, int **ls, Constraint_list *CL, int
   int **pos;
   if (!A)return 0;
   
-//   printf("ICH BIN HIER\n");
+
   if ( list_in[0] && list_in[0][0]==0)
-	  return read_array_size (list, sizeof (int*));
+	  return read_array_size (list_in[0], sizeof (int*));
   
-//   printf("UND HIER IRGENDWIE AUCH\n");
+
   
   list=list_in[0];
   n=n_in[0];
@@ -1799,7 +1798,7 @@ int cl2pair_list_diag_mat ( Alignment *A, int *ns, int **ls, Constraint_list *CL
 int cl2pair_list_diag_cl ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in, int add );	  
 int cl2pair_list_diag ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in, int add )
 {
-  if (CL->L)return cl2pair_list_diag_cl (A, ns, ls, CL, list_in, n_in, add);
+  if (CL->residue_index)return cl2pair_list_diag_cl (A, ns, ls, CL, list_in, n_in, add);
   else return cl2pair_list_diag_mat (A, ns, ls, CL, list_in, n_in, add);
 }
 int cl2pair_list_diag_mat ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in, int add )
@@ -1975,11 +1974,15 @@ int cl2pair_list_ecl ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int
 {
   int mode=5;
   
+  if (atoigetenv ("ECLMODE4TC")){HERE ("****ECLMODE4TC:%d",mode=atoigetenv ("ECLMODE4TC"));}
+  
   if ( mode==1)return cl2pair_list_ecl_norm         (A, ns, ls, CL, list_in, n_in);
   else if ( mode==2)return cl2pair_list_ecl_raw     (A, ns, ls, CL, list_in, n_in);
   else if ( mode==3)return cl2pair_list_ecl_rawquad (A, ns, ls, CL, list_in, n_in);
   else if ( mode==4)return cl2pair_list_ecl_noext_raw (A, ns, ls, CL, list_in, n_in);
   else if ( mode==5)return cl2pair_list_ecl_pc     (A, ns, ls, CL, list_in, n_in);
+  else if ( mode==6)return cl2pair_list_ecl_ext_pc     (A, ns, ls, CL, list_in, n_in);
+  
 }
 int cl2pair_list_ecl_noext_raw ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
 {
@@ -2017,7 +2020,7 @@ int cl2pair_list_ecl_noext_raw ( Alignment *A, int *ns, int **ls, Constraint_lis
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
  
-  CL=index_res_constraint_list (CL, CL->weight_field);
+
   
   used=declare_int (l2+1,2);
   used_list=vcalloc (l2+1, sizeof (int));
@@ -2028,9 +2031,12 @@ int cl2pair_list_ecl_noext_raw ( Alignment *A, int *ns, int **ls, Constraint_lis
       for (nused=0,si=0;p1>0 && si<ns[0]; si++)
 	{
 	  s=ls [0][si];r=pos[s][p1-1];
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
-	      t_s2=CL->residue_index[s][r][a];t_r2=CL->residue_index[s][r][a+1];t_w2=CL->residue_index[s][r][a+2];
+	      t_s2=CL->residue_index[s][r][a+SEQ2];
+	      t_r2=CL->residue_index[s][r][a+R2];
+	      t_w2=CL->residue_index[s][r][a+WE];
+	      
 	      if (sl2[t_s2])
 		{
 		  p2=inv_pos[t_s2][t_r2];
@@ -2119,7 +2125,7 @@ int cl2pair_list_ecl_raw ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
   
-  CL=index_res_constraint_list (CL, CL->weight_field);
+
   
   used=declare_int (l2+1,2);
   used_list=vcalloc (l2+1, sizeof (int));
@@ -2130,15 +2136,20 @@ int cl2pair_list_ecl_raw ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
       for (tot=0,nused=0,si=0;p1>0 && si<ns[0]; si++)
 	{
 	  s=ls [0][si];r=pos[s][p1-1];
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
-	      t_s=CL->residue_index[s][r][a];t_r=CL->residue_index[s][r][a+1];t_w=CL->residue_index[s][r][a+2];
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
 	      for (b=0; b<CL->residue_index[t_s][t_r][0];)
 		{
 		  if (b==0){t_s2=t_s;t_r2=t_r;t_w2=t_w;b++;}
 		  else 
 		    { 
-		      t_s2=CL->residue_index[t_s][t_r][b];t_r2=CL->residue_index[t_s][t_r][b+1];t_w2=CL->residue_index[t_s][t_r][b+2];b+=3;
+		      t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		      t_r2=CL->residue_index[t_s][t_r][b+R2];
+		      t_w2=CL->residue_index[t_s][t_r][b+WE];
+		      b+=ICHUNK;
 		    }
 		  
 		  if (sl2[t_s2])
@@ -2227,6 +2238,10 @@ int cl2pair_list_ecl_raw ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
  * \param list_in the diagonals
  * \param n_in number of sequences?
  */
+
+
+
+
 int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
 {
   int p1, p2, si, s, r, t_s, t_r,t_w, t_s2, t_r2, t_w2, n;
@@ -2268,8 +2283,7 @@ int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
   
-  CL=index_res_constraint_list (CL, CL->weight_field);
-  
+    
   used=declare_float (l2+1,2);
   used_list=vcalloc (l2+1, sizeof (int));
   nused=0;
@@ -2280,15 +2294,20 @@ int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
       for (tot=0,nused=0,si=0;p1>0 && si<ns[0]; si++)
 	{
 	  s=ls [0][si];r=pos[s][p1-1];
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
-	      t_s=CL->residue_index[s][r][a];t_r=CL->residue_index[s][r][a+1];t_w=CL->residue_index[s][r][a+2];
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
 	      for (b=0; b<CL->residue_index[t_s][t_r][0];)
 		{
 		  if (b==0){t_s2=t_s;t_r2=t_r;t_w2=t_w;b++;}
 		  else 
 		    { 
-		      t_s2=CL->residue_index[t_s][t_r][b];t_r2=CL->residue_index[t_s][t_r][b+1];t_w2=CL->residue_index[t_s][t_r][b+2];b+=3;
+		      t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		      t_r2=CL->residue_index[t_s][t_r][b+R2];
+		      t_w2=CL->residue_index[t_s][t_r][b+WE];
+		      b+=ICHUNK;
 		    }
 		  
 		  if (sl2[t_s2])
@@ -2353,7 +2372,6 @@ int cl2pair_list_ecl_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
   return avg;
 }
 
-
 int cl2pair_list_ecl_rawquad ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
 {
   int p1, p2, si, s, r, t_s, t_r,t_w, t_s2, t_r2, t_w2,t_s3, t_r3, t_w3, n,n2;
@@ -2388,7 +2406,6 @@ int cl2pair_list_ecl_rawquad ( Alignment *A, int *ns, int **ls, Constraint_list
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
  
-  CL=index_res_constraint_list (CL, CL->weight_field);
   
   used=declare_int (l2+1,2);
   used_list=vcalloc (l2+1, sizeof (int));
@@ -2400,15 +2417,20 @@ int cl2pair_list_ecl_rawquad ( Alignment *A, int *ns, int **ls, Constraint_list
       for (nused=0,si=0;p1>0 && si<ns[0]; si++)
 	{
 	  s=ls [0][si];r=pos[s][p1-1];
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
-	      t_s=CL->residue_index[s][r][a];t_r=CL->residue_index[s][r][a+1];t_w=CL->residue_index[s][r][a+2];
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
 	      for (b=0; b<CL->residue_index[t_s][t_r][0];)
 		{
 		  if (b==0){t_s2=t_s;t_r2=t_r;t_w2=t_w;b++;}
 		  else 
 		    { 
-		      t_s2=CL->residue_index[t_s][t_r][b];t_r2=CL->residue_index[t_s][t_r][b+1];t_w2=CL->residue_index[t_s][t_r][b+2];b+=3;
+		      t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		      t_r2=CL->residue_index[t_s][t_r][b+R2];
+		      t_w2=CL->residue_index[t_s][t_r][b+WE];
+		      b+=ICHUNK;
 		    }
 		  if (sl2[t_s2])
 		    {
@@ -2417,7 +2439,10 @@ int cl2pair_list_ecl_rawquad ( Alignment *A, int *ns, int **ls, Constraint_list
 			  if (c==0){t_s3=t_s2;t_r3=t_r2;t_w3=t_w2;c++;}
 			  else 
 			    { 
-			      t_s3=CL->residue_index[t_s2][t_r2][c];t_r3=CL->residue_index[t_s2][t_r2][c+1];t_w3=CL->residue_index[t_s2][t_r2][c+2];c+=3;
+			      t_s3=CL->residue_index[t_s2][t_r2][c+SEQ2];
+			      t_r3=CL->residue_index[t_s2][t_r2][c+R2];
+			      t_w3=CL->residue_index[t_s2][t_r2][c+WE];
+			      c+=ICHUNK;
 			    }
 			  
 			  if (sl2[t_s3])
@@ -2504,7 +2529,6 @@ int cl2pair_list_ecl_norm ( Alignment *A, int *ns, int **ls, Constraint_list *CL
   
   for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
  
-  CL=index_res_constraint_list (CL, CL->weight_field);
   
   used=vcalloc (l2+1, sizeof (int));
   used_list=vcalloc (l2+1, sizeof (int));
@@ -2519,17 +2543,21 @@ int cl2pair_list_ecl_norm ( Alignment *A, int *ns, int **ls, Constraint_list *CL
 	  s=ls [0][si];
 	  r=pos[s][p1-1];
 	  
-	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=3)
+	  for (a=1; r>0 && a<CL->residue_index[s][r][0];a+=ICHUNK)
 	    {
 	      
-	      t_s=CL->residue_index[s][r][a];
-	      t_r=CL->residue_index[s][r][a+1];
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
 	      
 	      for (b=0; b<CL->residue_index[t_s][t_r][0];)
 		{
 		  int t_s2, t_r2;
 		  if (b==0){t_s2=t_s;t_r2=t_r;b++;}
-		  else { t_s2=CL->residue_index[t_s][t_r][b];t_r2=CL->residue_index[t_s][t_r][b+1];b+=3;}
+		  else { 
+		    t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		    t_r2=CL->residue_index[t_s][t_r][b+R2];
+		    b+=ICHUNK;
+		  }
 		  
 		  if (sl2[t_s2])
 		    {
@@ -2627,6 +2655,202 @@ int cl2pair_list_ref( Alignment *A, int *ns, int **ls, Constraint_list *CL, int
   return n[0];
   }
 
+/**
+ * Calculates scores for diagonal segments.
+ * 
+ * \param Alignment The sequences.
+ * \param ns Number of sequences in each group
+ * \param ls sequences in in groups (ls[0][x] sequences in group 1, ls[1][x] squences in group 2).
+ * \param CL the constraint list
+ * \param list_in the diagonals
+ * \param n_in number of sequences?
+ */
+int cl2pair_list_ecl_ext_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in)
+{
+  int **list, **pos, **cache, **reallocT;
+  int  *sl2;
+  int si,a,b,n, l1, l2, p1, p2,s,r;
+  int t_s , t_r , t_w;
+  int t_s2, t_r2, t_w2;
+  int max_len,nseq, avg;
+  int tot=0;
+  
+  
+  if ( !A) return 0;
+  list=list_in[0];
+  n=n_in[0];
+  
+  pos=aln2pos_simple ( A,-1, ns, ls);
+  l1=strlen (A->seq_al[ls[0][0]]);
+  l2=strlen (A->seq_al[ls[1][0]]);
+  sl2=vcalloc ((CL->S)->nseq, sizeof (int));
+  for (a=0;a<ns[1]; a++)sl2[ls[1][a]]=1;
+  
+  max_len=(CL->S)->max_len;
+  nseq=(CL->S)->nseq;
+  
+  cache=declare_int ( nseq+1, max_len+1);
+  reallocT=declare_int (nseq+1, max_len+1);
+  
+  for (p1=1; p1<=l1; p1++)
+    {
+      for (si=0;si<ns[0]; si++)
+	{
+	  s=ls[0][si];r=pos[s][p1-1];
+	  s=name_is_in_list (A->name[s], (CL->S)->name, (CL->S)->nseq, 100);
+	  if (r<=0)continue;
+	  cache[s][r]=1;
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      cache[t_s][t_r]=1;
+	    }
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      for (b=1; b<CL->residue_index[t_s][t_r][0];b+=ICHUNK)
+		{
+		  t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		  t_r2=CL->residue_index[t_s][t_r][b+R2];
+		  t_w2=CL->residue_index[t_s][t_r][b+WE];
+		  
+		  if (!cache[t_s2][t_r2])
+		    {
+		      tot++;
+		      int ni;
+		      cache[t_s2][t_r2]=1;
+		      if (!reallocT[s][r])reallocT[s][r]=CL->residue_index[s][r][0];
+		      ni=CL->residue_index[s][r][0];
+		      CL->residue_index[s][r][0]+=ICHUNK;
+		      
+		      CL->residue_index[s][r]=vrealloc ( CL->residue_index[s][r], CL->residue_index[s][r][0]*sizeof (int));
+		      CL->residue_index[s][r][ni+SEQ2]=t_s2;
+		      CL->residue_index[s][r][ni+R2]=t_r2;
+		      CL->residue_index[s][r][ni+WE]=MIN(t_w2,t_w);
+		      
+		      if (!reallocT[t_s2][t_r2])reallocT[t_s2][t_r2]=CL->residue_index[t_s2][t_r2][0];
+		      ni=CL->residue_index[t_s2][t_r2][0];
+		      CL->residue_index[t_s2][t_r2][0]+=ICHUNK;
+		      CL->residue_index[t_s2][t_r2]=vrealloc ( CL->residue_index[t_s2][t_r2], CL->residue_index[t_s2][t_r2][0]*sizeof (int));
+		      CL->residue_index[t_s2][t_r2][ni+SEQ2]=s;
+		      CL->residue_index[t_s2][t_r2][ni+R2]=r;
+		      CL->residue_index[t_s2][t_r2][ni+WE]=MIN(t_w2,t_w);
+		      
+		    }
+		}
+	      
+	    }
+
+	  cache[s][r]=0;
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      cache[t_s][t_r]=0;
+	    }
+	}
+    }
+
+  for (p1=1; p1<=l2; p1++)
+    {
+      for (si=0;si<ns[1]; si++)
+	{
+	  s=ls[1][si];r=pos[s][p1-1];
+	  s=name_is_in_list (A->name[s], (CL->S)->name, (CL->S)->nseq, 100);
+	  if (r<=0)continue;
+	  cache[s][r]=1;
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      cache[t_s][t_r]=1;
+	    }
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      for (b=1; b<CL->residue_index[t_s][t_r][0];b+=ICHUNK)
+		{
+		  t_s2=CL->residue_index[t_s][t_r][b+SEQ2];
+		  t_r2=CL->residue_index[t_s][t_r][b+R2];
+		  t_w2=CL->residue_index[t_s][t_r][b+WE];
+		  
+		  if (!cache[t_s2][t_r2])
+		    {
+		      tot++;
+		      int ni;
+		      
+		      cache[t_s2][t_r2]=1;
+		      if (!reallocT[s][r])reallocT[s][r]=CL->residue_index[s][r][0];
+		      ni=CL->residue_index[s][r][0];
+		      CL->residue_index[s][r][0]+=ICHUNK;
+		      CL->residue_index[s][r]=vrealloc ( CL->residue_index[s][r], CL->residue_index[s][r][0]*sizeof (int));
+		      CL->residue_index[s][r][ni+SEQ2]=t_s2;
+		      CL->residue_index[s][r][ni +R2]=t_r2;
+		      CL->residue_index[s][r][ni+WE]=MIN(t_w2,t_w);
+		      
+		      if (!reallocT[t_s2][t_r2])reallocT[t_s2][t_r2]=CL->residue_index[t_s2][t_r2][0];
+		      ni=CL->residue_index[t_s2][t_r2][0];
+		      CL->residue_index[t_s2][t_r2][0]+=ICHUNK;
+		      CL->residue_index[t_s2][t_r2]=vrealloc ( CL->residue_index[t_s2][t_r2], CL->residue_index[t_s2][t_r2][0]*sizeof (int));
+		      CL->residue_index[t_s2][t_r2][ni+SEQ2]=s;
+		      CL->residue_index[t_s2][t_r2][ni+R2]=r;
+		      CL->residue_index[t_s2][t_r2][ni+WE]=MIN(t_w2,t_w);
+		      
+		    }
+		}
+	      
+	    }
+
+	  cache[s][r]=0;
+	  for (a=1;a<CL->residue_index[s][r][0];a+=ICHUNK)
+	    {
+	      
+	      
+	      t_s=CL->residue_index[s][r][a+SEQ2];
+	      t_r=CL->residue_index[s][r][a+R2];
+	      t_w=CL->residue_index[s][r][a+WE];
+	      
+	      cache[t_s][t_r]=0;
+	    }
+	}
+    }
+
+  
+
+  HERE ("TOT=%d", tot);
+  avg=cl2pair_list_ecl_pc (A, ns,ls, CL,list_in,n_in);
+  
+  for (s=0; s<=nseq; s++)
+    for (r=0; r<=max_len; r++)
+      if ( reallocT[s][r])CL->residue_index[s][r][0]=reallocT[s][r];
+  free_int (reallocT, -1);
+  free_int (cache, -1);
+  return avg;
+}
+
 int list2linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL, int **list, int n);
 int two_pass_linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
 {
@@ -2680,6 +2904,9 @@ int linked_pair_wise ( Alignment *A, int *nsi, int **lsi, Constraint_list *CL)
   int *ns, **ls;
   int mode=1;//1:ecl, 0:ref
 
+  if ( !CL->residue_index)return myers_miller_pair_wise (A, nsi,lsi,CL);
+  
+
   ns=vcalloc (2, sizeof (int));
   ns[0]=nsi[1]; ns[1]=nsi[0];
   
@@ -3036,7 +3263,7 @@ int ** aln2local_penalties4link (Alignment *A, int n, int *ls, Constraint_list *
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
