@@ -186,7 +186,7 @@ int suboptimal_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
   
   id=idscore_pairseq(seqI,seqJ,-12, -1, CL->M, "idmat");
   
-  entry=vcalloc ( CL->entry_len, CL->el_size);
+  entry=vcalloc ( CL->entry_len+1, CL->el_size);
   entry[SEQ1]=s1;entry[SEQ2]=s2;
   
   thres=opt;
@@ -203,6 +203,7 @@ int suboptimal_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL,
 	      entry[R1]=i;entry[R2]=j;
 	      entry[WE]=id;
 	      entry[CONS]=1;
+	      
 	      add_entry2list (entry,A->CL);
 	    }
 	}
@@ -608,9 +609,9 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
    static float **transMat, **insProb, **matchProb, *initialDistribution, **transProb, **emitPairs, *emitSingle, ***TinsProb, *TmatchProb;
    static int TinsProb_ml, TmatchProb_ml;
    int i, j,I, J;
-   float *F, *B, *P;
-   float tot;
-   int l, s1, s2;
+   float *F, *B;
+   
+   int l;
    float thr=0.01;//ProbCons Default
    char *alphabet;
   
@@ -669,7 +670,7 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
        
        for (i=0; i<l; i++)
 	 {
-	   char C1,c1, C2,c2;
+	   int C1,c1, C2,c2;
 	   c1=tolower(alphabet[i]);
 	   C1=toupper(alphabet[i]);
 	   emitSingle[c1]=s[i];
@@ -733,7 +734,7 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
        
        for (i=0; i<l; i++)
 	 {
-	   char C1,c1, C2,c2;
+	   int C1,c1, C2,c2;
 	   c1=tolower(alphabet[i]);
 	   C1=toupper(alphabet[i]);
 	   emitSingle[c1]=s[i];
@@ -798,9 +799,13 @@ int proba_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
 int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, float **matchProb, float **insProb, float *TmatchProb, float ***TinsProb, Constraint_list *CL)
 {
   int i, j, a, b, c,d, k, n,n1,n2, ij;
-  char c1, c2;
+  int  c1, c2;
   int I, J;
   int ***VA1,***VA2, *observed, index;
+  char *ss1=NULL;
+  char *ss2=NULL;
+  int uss=0;
+  
   //Pre-computation of the pairwise scores in order to use potential profiles
   //The profiles are vectorized AND Compressed so that the actual alphabet size (proteins/DNA) does not need to be considered
   
@@ -810,6 +815,9 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
       int s1, s2;
       int *nns, **nls;
       Alignment *NA1, *NA2;
+      char *sst1;
+      char *sst2;
+
       
       nns=vcalloc ( 2, sizeof (int));
       nls=vcalloc (2, sizeof (int*));
@@ -819,6 +827,9 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
       NA1=seq2R_template_profile (CL->S,s1);
       NA2=seq2R_template_profile (CL->S,s2);
       
+      sst1=seq2T_template_string((CL->S),s1);
+      sst2=seq2T_template_string((CL->S),s2);
+      
       if (NA1 || NA2)
 	{
 	  if (NA1)
@@ -827,6 +838,8 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	      nls[0]=vcalloc (NA1->nseq, sizeof (int));
 	      for (a=0; a<NA1->nseq; a++)
 		nls[0][a]=a;
+	      NA1->seq_al[NA1->nseq]=sst1;
+	      sprintf (NA1->name[NA1->nseq], "sst1");
 	    }
 	  else
 	    {
@@ -842,7 +855,9 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	      nns[1]=NA2->nseq;
 	      nls[1]=vcalloc (NA2->nseq, sizeof (int));
 	      for (a=0; a<NA2->nseq; a++)
-		nls[1][a]=a;
+		nls[1][a]=a;	      
+	      NA2->seq_al[NA2->nseq]=sst2;
+	      sprintf (NA2->name[NA2->nseq], "sst2");
 	    }
 	  else 
 	    {
@@ -858,7 +873,15 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	  return 1;
 	}
     }
-      
+  if ( A1!=A2)
+    {
+      if (strm (A1->name[A1->nseq], "sst1"))ss1=A1->seq_al[A1->nseq];
+      if (strm (A2->name[A2->nseq], "sst2"))ss2=A2->seq_al[A2->nseq];
+      uss=(ss1&&ss2)?1:0;
+    }
+  else
+    uss=0;
+  
   I=strlen (A1->seq_al[ls[0][0]]);
   J=strlen (A2->seq_al[ls[1][0]]);
   
@@ -954,6 +977,13 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 	  if (i==0 || j==0);
 	  else
 	    {
+	      float sfac;
+	      if (!uss)sfac=1;
+	      else if (ss1[i-1]!=ss2[j-1])sfac=1;
+	      else if (ss1[i-1]==ss2[j-1])sfac=1;
+	      else sfac=1;
+	      
+	     
 	      c=0;
 	      while (VA1[0][c][i-1]!=-1)
 		{
@@ -964,7 +994,7 @@ int get_tot_prob (Alignment *A1,Alignment *A2, int *ns, int **ls, int nstates, f
 		    {
 		      c2=VA2[0][d][j-1]+'a';
 		      n2=VA2[1][d][j-1];
-		      TmatchProb[ij]+=matchProb[c1][c2]*(double)n1*(double)n2;
+		      TmatchProb[ij]+=matchProb[c1][c2]*(double)n1*(double)n2*sfac;
 		      n+=n1*n2;
 		      d++;
 		    }
@@ -1042,7 +1072,8 @@ Constraint_list *ProbaMatrix2CL (Alignment *A, int *ns, int **ls, int NumMatrixT
     }
 
   sort_int_inv (list, 3, 2, 0, list_n-1);
-  if (!entry)entry=vcalloc ( CL->entry_len, CL->el_size);
+  if (!entry)entry=vcalloc ( CL->entry_len+1, CL->el_size);
+ 
   list_n=MIN(list_n,(F*MIN(I,J)));
   for (i=0; i<list_n; i++)
     {
@@ -1074,7 +1105,7 @@ Constraint_list *ProbaMatrix2CL_old (Alignment *A, int *ns, int **ls, int NumMat
   s2=name_is_in_list (A->name[ls[1][0]], (CL->S)->name, (CL->S)->nseq, 100);
   
   totalProb = ComputeTotalProbability (I,J,NumMatrixTypes, NumInsertStates,forward, backward);
-  if (!entry)entry=vcalloc ( CL->entry_len, CL->el_size);
+  if (!entry)entry=vcalloc ( CL->entry_len+1, CL->el_size);
   ij = 0;
   thr=0.01;
 
@@ -1365,7 +1396,7 @@ int ProbabilisticModel (int NumMatrixTypes, int NumInsertStates,float *initDistr
 
 int viterbi_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL)
 {
-  char C1,c1, C2,c2;
+  int C1,c1, C2,c2;
   char *alphabet, *char_buf;
   char **al, **aln;
   int seq1Length, seq2Length, I, J;
@@ -1628,7 +1659,7 @@ float ** get_emitPairs (char *mat, char *alp, float **p, float *s)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
