@@ -79,7 +79,7 @@ Job_TC *print_lib_job2 ( Job_TC* job, int n, char **name, char **value)
       else if ( strstr(name[a], "io") && !job->io){job->io=vcalloc ( 1, sizeof (Job_io_TC));job->pl[job->np++]=(void*)job->io;}
       else if ( strstr(name[a], "param") && !job->param){job->param=vcalloc ( 1, sizeof (Job_param_TC));job->pl[job->np++]=(void*)job->param;}
       
-      if (           strm (name[a], "control"))                {job->control=(struct Job_control_TC*)atoi(value[a]);string=0;}
+      if (           strm (name[a], "control"))                {job->control=(struct Job_control_TC*)atol(value[a]);string=0;}
       else if (      strm (name[a], "control->submitF"))       {(job->control) ->submitF=(struct Job_TC *(*)(struct Job_TC *))atol(value[a]);string=0;}
       else if (      strm (name[a], "control->retrieveF"))     {(job->control) ->retrieveF=(struct Job_TC *(*)(struct Job_TC *))atol(value[a]);string=0;}
       else if (      strm (name[a], "control->mode"))   {(job->control)->mode=value[a];string=1;}
@@ -273,7 +273,7 @@ Job_TC*** split_job_list (Job_TC *job, int ns)
   
     a=0;
     while (jl[a]){HERE ("**** %d %d ", jl [a][0], jl[a][1]);a++;}
-    exit (0);
+    myexit (0);
   */
   return jl;
 }
@@ -315,7 +315,7 @@ Job_TC* retrieve_job ( Job_TC *job)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Tue Mar 30 19:55:28 WEDT 2010. */
+/*Thu Jun 24 13:19:29 CEST 2010. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
